/***************************** C HEADER FILE *********************************
**
**  Project:    API for RTCU Deployment Server monitor
**  Filename:   RDSAPI.H 
**  
******************************************************************************
**
**
*****************************************************************************/
#ifndef _RDSAPI_H_INCLUDED_
#define _RDSAPI_H_INCLUDED_

#ifdef __cplusplus
extern "C" {
#endif


/*****************************************************************************
**
**    MODULES USED 
**
*****************************************************************************/


/*****************************************************************************
**
**    DEFINITIONS AND MACROS
**
*****************************************************************************/
// Profile flags
#define PFLAG_AUTORESET                   0x00000001
#define PFLAG_SETPASSWORD                 0x00000002
#define PFLAG_DEACTIVATE                  0x00000004
#define PFLAG_APP_ENABLE                  0x00000008
#define PFLAG_FW_ENABLE                   0x00000010
#define PFLAG_FORCEHALT                   0x00000020
#define PFLAG_TARGETDEFAULT               0x00000040
#define PFLAG_FILE_ENABLE                 0x00000080
#define PFLAG_NO_DOWNGRADE_APP            0x00000100
#define PFLAG_NO_DOWNGRADE_FW             0x00000200
#define PFLAG_APP_NEWER                   0x00000400
#define PFLAG_APP_OLDER                   0x00000800
#define PFLAG_FW_NEWER                    0x00001000
#define PFLAG_FW_OLDER                    0x00002000
#define PFLAG_APP_INFILE                  0x40000000

#define FLAG_ENABLE                       0x00000001
#define FLAG_DOWNGRADE                    0x00000002
#define FLAG_NEWER                        0x00000004
#define FLAG_OLDER                        0x00000008
#define FLAG_DELETE                       0x00000010

// Unit info flags
#define UFLAG_OPTIONS_MASK                0xFFFF0000
#define UFLAG_DEACTIVATE                  0x00010000

// Unit import flags
#define RDS_IMPORT_OVERWRITE              1

// Unit info status
#define USTATUS_NO_INFO                    0
#define USTATUS_NOT_CONNECTED              1
#define USTATUS_UP_TO_DATE                 2
#define USTATUS_DEACTIVATED_PROFILE        3
#define USTATUS_DEACTIVATED                4
#define USTATUS_TRANSFER_IN_QUEUE          5
#define USTATUS_TRANSFER_APP               6
#define USTATUS_TRANSFER_FW                7
#define USTATUS_WAIT_FOR_RESET             8
#define USTATUS_WAIT_FOR_TIME              9
#define USTATUS_TRANSFER_FILE             10
#define USTATUS_ERROR_APP                 30
#define USTATUS_ERROR_FW                  31
#define USTATUS_ERROR_FILE_APP            32
#define USTATUS_ERROR_FILE_APP_INVALID    33
#define USTATUS_ERROR_FILE_FW             34
#define USTATUS_ERROR_FILE_FW_INVALID     35
#define USTATUS_ERROR_PASSWORD            36
#define USTATUS_ERROR_TRANSFER            37
#define USTATUS_ERROR_FILE_TRANSFER       38

// Target definitions
#define TARGET_A9                           9
#define TARGET_M10                         10
#define TARGET_M11                         11
#define TARGET_MX2                        102
#define TARGET_DX4MK2                     103
#define TARGET_DX4                        104
#define TARGET_CX1                        105
#define TARGET_SX1                        106
#define TARGET_AX9                        109
#define TARGET_MX2T                       122
#define TARGET_AX9T                       129
#define TARGET_MX2SOM                     192
#define TARGET_EGATE                      201
#define TARGET_NX400                      204
#define TARGET_LTGW                       211


/****************************************************************************
**
**    TYPEDEFS AND STRUCTURES
**
****************************************************************************/

#pragma pack (push, before)
#pragma pack(1)

struct rds_fw_limit_t
{
   int            system;
   int            runtime;
};

struct rds_firmware_t
{
   int                        flags;
   int                        target;
   int                        system;
   int                        runtime;
   int                        monitor;
   rds_fw_limit_t             newer;
   rds_fw_limit_t             older;
   char                       file[191];
};

struct rds_application_t
{
   int                        flags;
   int                        newer;
   int                        older;
   int                        version;
   char                       file[191];
   char                       name[16];
};

struct rds_folder_t
{
   int                        flags;
   int                        media;
   char                       folder[191];
};

typedef struct rdsProfileInfo {
   long           id_number;      //id number of the profile
   char           name[65];
   char           password[21];
   int            flags;
   long           time_start;     //start time of transfer time interval (in seconds)
   long           time_stop;      //stop time of transfer time interval (in seconds)

   char           app_name[16];   //application name. (15 chars + zero terminator)
   short          app_ver;        //application version (scaled by 100)
   char           app_file[191];  //application filename. (190 chars + zero terminator)

   short          fw_tgt;         //firmware target ID.
   int            fw_system;      //firmware system version
   int            fw_runtime;     //firmware runtime version
   int            fw_monitor;     //firmware runtime version
   char           fw_file[191];   //firmware filename. (190 chars + zero terminator)

   char           file_file[191]; //filename of generic file. (190 chars + zero terminator)
   char           file_dst[61];

   int            app_newer;      //application policy: Only newer than
   int            app_older;      //application policy: Only older than
   rds_fw_limit_t fw_newer;       //firmware policy: Only newer than
   rds_fw_limit_t fw_older;       //firmware policy: Only older than
} rdsProfileInfo;

typedef struct rdsProfileInfo1 {
   long                       size;           //the size of the structure in bytes
   long                       id_number;      //id number of the profile
   char                       name[65];
   char                       password[21];
   int                        flags;
   long                       time_start;     //start time of transfer time interval (in seconds)
   long                       time_stop;      //stop time of transfer time interval (in seconds)

   char                       file_file[191]; //filename of generic file. (190 chars + zero terminator)
   char                       file_dst[61];

   struct rds_firmware_t      system;         //system firmware
   struct rds_firmware_t      runtime;        //runtime firmware
   struct rds_firmware_t      monitor;        //monitor firmware
   struct rds_application_t   app;            //application
   struct rds_folder_t        folder;         //folder watch
} rdsProfileInfo1;

typedef struct rdsUnitInfo {
   long           serial_number; //serial number of the unit
   long           profile_id;    //id number of the profile
   char           password[21];
   int            flags;
   char           app_name[16];  //application name. (15 chars + zero terminator)
   short          app_ver;       //application version (scaled by 100)
   short          fw_tgt;        //Target ID of the device.
   int            fw_system;     //system version
   int            fw_runtime;    //runtime version
   int            fw_monitor;    //monitor version
   char           progress;      //transfer progress in percent (%)
   char           gateway;       //index of the Gateway the unit is connected to
   short          status;
   time_t         timestamp;
   char           comment[101];
} rdsUnitInfo;

typedef struct rdsImportUnit {
   long           serial_number; //serial number of the unit to import
   long           profile_id;    //id number of the profile for the imported unit
   char           flag;          //Enable/Disable flag
   char           comment[101];  //comment about the unit
} rdsImportUnit;

#pragma pack(pop, before)

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the Log data received notification callback.
//
// Input:
//    arg        - A user supplied argument.
//    timestamp  - The timestamp for the log entry.
//    text       - The text for the log entry. (Zero terminated ASCII text)
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*notify_log_data)(void* arg, const time_t timestamp, const char* text);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the Log cleared notification callback.
//
// Input:
//    arg        - A user supplied argument.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*notify_log_clear)(void* arg);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the profile data received notification callback.
//
// Input:
//    arg        - A user supplied argument.
//    item       - Pointer to a structure holding the profile data.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*notify_profile_data)(void* arg, const rdsProfileInfo* item);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the profile data received notification callback.
//
// Input:
//    arg        - A user supplied argument.
//    item       - Pointer to a structure holding the profile data.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*notify_profile1_data)(void* arg, const rdsProfileInfo1* item);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the profile deleted notification callback.
//
// Input:
//    arg        - A user supplied argument.
//    ID         - The ID of the profile that is deleted.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*notify_profile_deleted)(void* arg, const long ID);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the unit data received notification callback.
//
// Input:
//    arg        - A user supplied argument.
//    item       - Pointer to a structure holding the unit data.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*notify_unit_data)(void* arg, const rdsUnitInfo* item);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the unit deleted notification callback.
//
// Input:
//    arg        - A user supplied argument.
//    ID         - The ID of the unit that is deleted.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*notify_unit_deleted)(void* arg, const long ID);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the filename callback, used when requesting
// a list of files. (Both application files, Firmware files and Folders)
//
// Input:
//    Filename   - The name of the file or directory. (Zero terminated ASCII text)
//    Target     - The target id of the firmware.
//                 -1 is returned for Application, Folder or File.
//    System     - The system version of the file.
//                 -1 is returned for Folder or File.
//    Runtime    - The runtime version of the file.
//                 -1 is returned for Folder or File,
//                 0 is returned for Application or Firmware without a runtime.
//    Name       - The name of the application. (Zero terminated ASCII text)
//                 An empty string is returned for Firmware and Folder.
//    arg        - A user supplied argument.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*cbFilename)(void*       arg,
                           const char* Filename,
                           const int   Target,
                           const int   System,
                           const int   Runtime,
                           const int   Monitor,
                           const char* Name);

/////////////////////////////////////////////////////////////////////////////
// This is the definition of the server connection status callback, used
// when requesting the status of the Gateway connections of the server.
//
// Input:
//    Name       - The name of the Gateway. (Zero terminated ASCII text)
//    Status     - Zero = Not connected, <> zero = Connected.
//    arg        - A user supplied argument.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
typedef void (*cbStatus)(void* arg, const char* Name, const char Status);


/****************************************************************************
** 
**    EXPORTED VARIABLES
**
****************************************************************************/


/****************************************************************************
**
**    EXPORTED FUNCTIONS
**
****************************************************************************/

/////////////////////////////////////////////////////////////////////////////
// Get the version of the RDS API library.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    The version of the RDSAPI library scaled by 100.
//
/////////////////////////////////////////////////////////////////////////////
int rdsGetVersion(void);

/////////////////////////////////////////////////////////////////////////////
// Open connection to Gateway and Logon to RDS server. The connection is
// opened and managed asynchronous. Use the rdsGetStatus function to determine
// when the RDSAPI library is connected.
//
// Input:
//    gw_addr    - The IP address of the gateway.
//    gw_port    - The IP port of the gateway.
//    gw_key     - The logon key for the gateway.
//    rds_key    - The logon key for the RDS server.
//
// Output:
//    None.
//
// Returns:
//    2          - Connection is already open.
//    1          - Illegal parameter.
//    0          - Success.
//
/////////////////////////////////////////////////////////////////////////////
int rdsConnect(const char*          gw_addr,
               const unsigned short gw_port,
               const char*          gw_key,
               const char*          rds_key);

/////////////////////////////////////////////////////////////////////////////
// Logoff from RDS server and disconnect from the Gateway.
// The connection is closed when the function returns.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void rdsDisconnect(void);

/////////////////////////////////////////////////////////////////////////////
// Get the status of the connection to the server.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//   15          - Unsupported RDS server.
//   14          - Incorrect RDS login password.
//   13          - All monitor slots on the server is in use.
//   12          - RDS not found.
//    4          - Connected to RDS.
//    3          - Connecting to RDS.
//    2          - Connected to gateway.
//    1          - Connecting to gateway.
//    0          - Not connected.
//
/////////////////////////////////////////////////////////////////////////////
int rdsGetStatus(void);

/////////////////////////////////////////////////////////////////////////////
// Get the version of the connected RDS server.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    The version of the RDS server scaled by 100.
//    -1         - Not connected to RDS server.
//
/////////////////////////////////////////////////////////////////////////////
int rdsGetServerVersion();

/////////////////////////////////////////////////////////////////////////////
// Register callback functions with RDSAPI library, which is then called to
// notify about log changes.
//
// Input:
//    arg        - A user supplied argument, that is included with the
//                 notifications.
//    data       - The function to notify when log data is received.
//                 (The received log data will be included)
//    clear      - The function to notify when log is cleared.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void rdsRegisterLogNotification(void*            arg,
                                notify_log_data  data,
                                notify_log_clear clear);

/////////////////////////////////////////////////////////////////////////////
// Request the RDS server log.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    1          - General error.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsLogLoad(void);

/////////////////////////////////////////////////////////////////////////////
// Clear the RDS server log.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsLogClear(void);

/////////////////////////////////////////////////////////////////////////////
// Register callback functions with RDSAPI library, which is then called to
// notify about profile changes.
//
// Input:
//    arg        - A user supplied argument, that is included with the
//                 notifications.
//    data       - The function to notify when profile data is received.
//                 (The received profile data will be included)
//    deleted    - The function to notify when a profile is deleted.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void rdsRegisterProfileNotification(void*                   arg,
                                    notify_profile_data     data,
                                    notify_profile_deleted  deleted);

/////////////////////////////////////////////////////////////////////////////
// Register callback functions with RDSAPI library, which is then called to
// notify about profile changes.
//
// Input:
//    data1      - The function to notify when profile data is received.
//                 (The received profile data will be included)
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void rdsRegisterProfile1Notification(notify_profile1_data data1);

/////////////////////////////////////////////////////////////////////////////
// Request the data of all the profiles on the RDS server.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    1          - General error.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsProfileLoad(void);

/////////////////////////////////////////////////////////////////////////////
// Create a new profile on the RDS server.
//
// Input:
//    Item       - Pointer to the structure that holds the profile data.
//
// Output:
//    None.
//
// Returns:
//    9          - No Application, Firmware and File is selected.
//    8          - Name is missing.
//    7          - Invalid time interval.
//    6          - Invalid firmware parameter.
//    5          - Invalid application parameter.
//    4          - Invalid file parameter.
//    3          - Other profile is set as default for target.
//    2          - Other profile with the same name.
//    1          - General error.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsProfileCreate(rdsProfileInfo* Item);

/////////////////////////////////////////////////////////////////////////////
// Create a new profile on the RDS server.
//
// Input:
//    Item       - Pointer to the structure that holds the profile data.
//
// Output:
//    None.
//
// Returns:
//    9          - No Application, Firmware and File is selected.
//    8          - Name is missing.
//    7          - Invalid time interval.
//    6          - Invalid firmware parameter.
//    5          - Invalid application parameter.
//    4          - Invalid file parameter.
//    3          - Other profile is set as default for target.
//    2          - Other profile with the same name.
//    1          - General error.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsProfile1Create(rdsProfileInfo1* Item);

/////////////////////////////////////////////////////////////////////////////
// Delete a profile from the RDS server.
//
// Input:
//    ID         - The ID of the profile.
//
// Output:
//    None.
//
// Returns:
//    2          - Profile is in use.
//    1          - Profile is not found.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsProfileDelete(long ID);

/////////////////////////////////////////////////////////////////////////////
// Edit the data of a profile on the RDS server.
//
// Input:
//    Item       - Pointer to the structure that holds the profile data.
//
// Output:
//    None.
//
// Returns:
//   10          - No Application, Firmware and File is selected.
//    9          - Name is missing.
//    8          - Invalid time interval.
//    7          - Invalid firmware parameter.
//    6          - Invalid application parameter.
//    5          - Invalid file parameter.
//    4          - Other profile is set as default for target.
//    3          - Other profile with the same name.
//    1          - Profile is not found.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsProfileEdit(rdsProfileInfo* Item);

/////////////////////////////////////////////////////////////////////////////
// Edit the data of a profile on the RDS server.
//
// Input:
//    Item       - Pointer to the structure that holds the profile data.
//
// Output:
//    None.
//
// Returns:
//   10          - No Application, Firmware and File is selected.
//    9          - Name is missing.
//    8          - Invalid time interval.
//    7          - Invalid firmware parameter.
//    6          - Invalid application parameter.
//    5          - Invalid file parameter.
//    4          - Other profile is set as default for target.
//    3          - Other profile with the same name.
//    1          - Profile is not found.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsProfile1Edit(rdsProfileInfo1* Item);

/////////////////////////////////////////////////////////////////////////////
// Request the number of profiles on the RDS server.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    The number of profiles on the RDS server
//    0          - Error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsProfileGetCount(void);

/////////////////////////////////////////////////////////////////////////////
// Register callback functions with RDSAPI library, which is then called to
// notify about unit changes.
//
// Input:
//    arg        - A user supplied argument, that is included with the
//                 notifications.
//    data       - The function to notify when unit data is received.
//                 (The received unit data will be included)
//    deleted    - The function to notify when a unit is deleted.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void rdsRegisterUnitNotification(void*                arg,
                                 notify_unit_data     data,
                                 notify_unit_deleted  deleted);

/////////////////////////////////////////////////////////////////////////////
// Request the data of all the units on the RDS server.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    1          - General error.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitLoad(void);

/////////////////////////////////////////////////////////////////////////////
// Create a new unit on the RDS server.
//
// Input:
//    ID         - The ID of the unit.
//    ProfileID  - The ID of the profile used.
//    flags      - The flags of the unit.
//    Password   - Zero terminated ASCII string with the unit password.
//    Comment    - Zero terminated ASCII string with comments about unit.
//
// Output:
//    None.
//
// Returns:
//    3          - Invalid parameter.
//    2          - Other unit exists.
//    1          - General error.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitCreate(const long  ID,
                  const long  ProfileID,
                  const int   flags,
                  const char* Password,
                  const char* Comment);

/////////////////////////////////////////////////////////////////////////////
// Delete a unit from the RDS server.
//
// Input:
//    ID         - The ID of the unit.
//
// Output:
//    None.
//
// Returns:
//    1          - Unit is not found.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitDelete(const long ID);

/////////////////////////////////////////////////////////////////////////////
// Edit a unit on the RDS server.
//
// Input:
//    ID         - The ID of the unit.
//    ProfileID  - The ID of the profile used.
//    flags      - The flags of the unit.
//    Password   - Zero terminated ASCII string with the unit password.
//    Comment    - Zero terminated ASCII string with comments about unit.
//
// Output:
//    None.
//
// Returns:
//    2          - Invalid parameter.
//    1          - Unit is not found.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitEdit(const long  ID,
                const long  ProfileID,
                const int   flags,
                const char* Password,
                const char* Comment);

/////////////////////////////////////////////////////////////////////////////
// Import a number of units to the RDS server.
//
// Input:
//    flags      - The flags for the units to import.
//    count      - The number of units in the array.
//    items      - Pointer to an array of structures that hold the units to
//                 import.
//
// Output:
//    None.
//
// Returns:
//    3          - Invalid parameter.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitImport(const char flags, const int count, rdsImportUnit* items);

/////////////////////////////////////////////////////////////////////////////
// Reset a number of units on the RDS server.
//
// Input:
//    count      - The number of units in the array.
//    units      - Pointer to an array that hold the unit ids.
//
// Output:
//    None.
//
// Returns:
//    1          - No units in array.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitReset(const int count, const long* units);

/////////////////////////////////////////////////////////////////////////////
// Refresh the information for a number of units on the RDS server.
//
// Input:
//    count      - The number of units in the array.
//    units      - Pointer to an array that hold the unit ids.
//
// Output:
//    None.
//
// Returns:
//    1          - No units in array.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitRefresh(const int count, const long* units);

/////////////////////////////////////////////////////////////////////////////
// Force an application transfer for a number of units on the RDS server.
//
// Input:
//    count      - The number of units in the array.
//    units      - Pointer to an array that hold the unit ids.
//
// Output:
//    None.
//
// Returns:
//    1          - No units in array.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitTransferForceApp(const int count, const long* units);

/////////////////////////////////////////////////////////////////////////////
// Force the transfer of a generic file for a number of units on the RDS server.
//
// Input:
//    count      - The number of units in the array.
//    units      - Pointer to an array that hold the unit ids.
//
// Output:
//    None.
//
// Returns:
//    1          - No units in array.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitTransferForceFile(const int count, const long* units);

/////////////////////////////////////////////////////////////////////////////
// Force a firmware transfer for a number of units on the RDS server.
//
// Input:
//    count      - The number of units in the array.
//    units      - Pointer to an array that hold the unit ids.
//
// Output:
//    None.
//
// Returns:
//    1          - No units in array.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitTransferForceFw(const int count, const long* units);

/////////////////////////////////////////////////////////////////////////////
// Force a firmware transfer for a number of units on the RDS server.
//
// Input:
//    count      - The number of units in the array.
//    units      - Pointer to an array that hold the unit ids.
//
// Output:
//    None.
//
// Returns:
//    1          - No units in array.
//    0          - Success.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsUnitTransferForceRuntime(const int count, const long* units);

/////////////////////////////////////////////////////////////////////////////
// Request a list of files from a folder.
//
// Input:
//    type       - The type of files.
//    Folder     - The path the the sub-directory to query.
//    cbFunc     - Pointer to the function that the RDSAPI will call with
//                 the files found in the Folder.
//    arg        - A user supplied argument, that is passed with the callback.
//
// Output:
//    None.
//
// Returns:
//    Number of files in the folder.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsGetFilelist(void*       arg,
                   cbFilename  cbFunc,
                   const int   type,
                   const char* Folder);

/////////////////////////////////////////////////////////////////////////////
// Request the server connection status.
//
// Input:
//    cbFunc     - Pointer to the function that the RDSAPI will call with
//                 the connection status for each Gateway.
//    arg        - A user supplied argument, that is passed with the callback.
//
// Output:
//    None.
//
// Returns:
//    Number of gateways the RDS server connects to.
//    -1         - Not connected to gateway.
//    -2         - RDS server not connected to gateway.
//    -3         - Communication error.
//
/////////////////////////////////////////////////////////////////////////////
int rdsGetServerStatus(void* arg, cbStatus cbFunc);


#ifdef __cplusplus
}
#endif

#endif  /* _RDSAPI_H_INCLUDED_ */
/****************************************************************************
**
**    EOF 
**
****************************************************************************/
